@@ -1,4 +1,5 @@
 """OpenAPI core testing requests module"""
+
 from typing import Any
 from typing import Dict
 from typing import Optional
@@ -20,8 +21,8 @@ class MockRequest:
         view_args: Optional[Dict[str, Any]] = None,
         headers: Optional[Dict[str, Any]] = None,
         cookies: Optional[Dict[str, Any]] = None,
-        data: Optional[str] = None,
-        mimetype: str = "application/json",
+        data: Optional[bytes] = None,
+        content_type: str = "application/json",
     ):
         self.host_url = host_url
         self.method = method.lower()
@@ -31,8 +32,8 @@ class MockRequest:
         self.view_args = view_args
         self.headers = headers
         self.cookies = cookies
-        self.body = data or ""
-        self.mimetype = mimetype
+        self.body = data or b""
+        self.content_type = content_type
 
         self.parameters = RequestParameters(
             path=self.view_args or {},
